aboutsummaryrefslogtreecommitdiff
path: root/src/wallet/wallet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/wallet/wallet.cpp')
-rw-r--r--src/wallet/wallet.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/wallet/wallet.cpp b/src/wallet/wallet.cpp
index 31cfd6095..107275b38 100644
--- a/src/wallet/wallet.cpp
+++ b/src/wallet/wallet.cpp
@@ -2845,8 +2845,8 @@ bool CWallet::AddAccountingEntry(const CAccountingEntry& acentry, CWalletDB *pwa
CAmount CWallet::GetRequiredFee(const CMutableTransaction& tx, unsigned int nTxBytes)
{
- // Dogecoin: Add an increased fee for each dust output
- return std::max(minTxFee.GetFee(nTxBytes) + GetDogecoinDustFee(tx.vout, minTxFee), ::minRelayTxFeeRate.GetFee(nTxBytes));
+ // Discoin: Add an increased fee for each dust output
+ return std::max(minTxFee.GetFee(nTxBytes) + GetDiscoinDustFee(tx.vout, minTxFee), ::minRelayTxFeeRate.GetFee(nTxBytes));
}
CAmount CWallet::GetRequiredFee(unsigned int nTxBytes)
@@ -2871,11 +2871,11 @@ CAmount CWallet::GetMinimumFee(const CMutableTransaction& tx, unsigned int nTxBy
//if (nFeeNeeded == 0)
// nFeeNeeded = fallbackFee.GetFee(nTxBytes);
// Dogecoin: Drop the smart fee estimate, use GetRequiredFee
nFeeNeeded = GetRequiredFee(tx, nTxBytes);
}
// prevent user from paying a fee below minRelayTxFee or minTxFee
// Dogecoin: as we're adapting minTxFee to never be higher than
// payTxFee unless explicitly set, this should be fine
nFeeNeeded = std::max(nFeeNeeded, GetRequiredFee(tx, nTxBytes));
@@ -2871,11 +2871,11 @@ CAmount CWallet::GetMinimumFee(const CMutableTransaction& tx, unsigned int nTxBy
//if (nFeeNeeded == 0)
// nFeeNeeded = fallbackFee.GetFee(nTxBytes);
- // Dogecoin: Drop the smart fee estimate, use GetRequiredFee
+ // Discoin: Drop the smart fee estimate, use GetRequiredFee
nFeeNeeded = GetRequiredFee(tx, nTxBytes);
}
@@ -2871,11 +2871,11 @@ CAmount CWallet::GetMinimumFee(const CMutableTransaction& tx, unsigned int nTxBy
}
// prevent user from paying a fee below minRelayTxFee or minTxFee
- // Dogecoin: as we're adapting minTxFee to never be higher than
+ // Discoin: as we're adapting minTxFee to never be higher than
// payTxFee unless explicitly set, this should be fine
nFeeNeeded = std::max(nFeeNeeded, GetRequiredFee(tx, nTxBytes));